Crate scrappy_testing

Crate scrappy_testing 

Various helpers for scrappy applications to use during testing.

Structs

TestServer
The TestServer type.
TestServerRuntime
Test server runstime

Attribute Macros

test
Marks async test function to be executed by scrappy runtime.